# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: anywhere/anywhere.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='anywhere/anywhere.proto',
  package='anywhere',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x17\x61nywhere/anywhere.proto\x12\x08\x61nywhere\"p\n\x05Where\x12.\n\x0fprimitive_value\x18\x01 \x01(\x0b\x32\x13.anywhere.PrimitiveH\x00\x12.\n\x0f\x63ondition_value\x18\x02 \x01(\x0b\x32\x13.anywhere.ConditionH\x00\x42\x07\n\x05value\"\x8a\x01\n\tPrimitive\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\n\n\x02op\x18\x02 \x01(\t\x12\x13\n\tint_value\x18\x03 \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\x04 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x05 \x01(\tH\x00\x12\x14\n\nbool_value\x18\x06 \x01(\x08H\x00\x42\x07\n\x05value\"L\n\tCondition\x12\x1e\n\x02op\x18\x01 \x01(\x0e\x32\x12.anywhere.Operator\x12\x1f\n\x06values\x18\x02 \x03(\x0b\x32\x0f.anywhere.Where*\x1b\n\x08Operator\x12\x07\n\x03\x41ND\x10\x00\x12\x06\n\x02OR\x10\x01\x62\x06proto3')
)

_OPERATOR = _descriptor.EnumDescriptor(
  name='Operator',
  full_name='anywhere.Operator',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AND', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OR', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=370,
  serialized_end=397,
)
_sym_db.RegisterEnumDescriptor(_OPERATOR)

Operator = enum_type_wrapper.EnumTypeWrapper(_OPERATOR)
AND = 0
OR = 1



_WHERE = _descriptor.Descriptor(
  name='Where',
  full_name='anywhere.Where',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='primitive_value', full_name='anywhere.Where.primitive_value', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='condition_value', full_name='anywhere.Where.condition_value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='anywhere.Where.value',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=37,
  serialized_end=149,
)


_PRIMITIVE = _descriptor.Descriptor(
  name='Primitive',
  full_name='anywhere.Primitive',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='field', full_name='anywhere.Primitive.field', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='op', full_name='anywhere.Primitive.op', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int_value', full_name='anywhere.Primitive.int_value', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='double_value', full_name='anywhere.Primitive.double_value', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='anywhere.Primitive.string_value', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bool_value', full_name='anywhere.Primitive.bool_value', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='anywhere.Primitive.value',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=152,
  serialized_end=290,
)


_CONDITION = _descriptor.Descriptor(
  name='Condition',
  full_name='anywhere.Condition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='op', full_name='anywhere.Condition.op', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='values', full_name='anywhere.Condition.values', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=292,
  serialized_end=368,
)

_WHERE.fields_by_name['primitive_value'].message_type = _PRIMITIVE
_WHERE.fields_by_name['condition_value'].message_type = _CONDITION
_WHERE.oneofs_by_name['value'].fields.append(
  _WHERE.fields_by_name['primitive_value'])
_WHERE.fields_by_name['primitive_value'].containing_oneof = _WHERE.oneofs_by_name['value']
_WHERE.oneofs_by_name['value'].fields.append(
  _WHERE.fields_by_name['condition_value'])
_WHERE.fields_by_name['condition_value'].containing_oneof = _WHERE.oneofs_by_name['value']
_PRIMITIVE.oneofs_by_name['value'].fields.append(
  _PRIMITIVE.fields_by_name['int_value'])
_PRIMITIVE.fields_by_name['int_value'].containing_oneof = _PRIMITIVE.oneofs_by_name['value']
_PRIMITIVE.oneofs_by_name['value'].fields.append(
  _PRIMITIVE.fields_by_name['double_value'])
_PRIMITIVE.fields_by_name['double_value'].containing_oneof = _PRIMITIVE.oneofs_by_name['value']
_PRIMITIVE.oneofs_by_name['value'].fields.append(
  _PRIMITIVE.fields_by_name['string_value'])
_PRIMITIVE.fields_by_name['string_value'].containing_oneof = _PRIMITIVE.oneofs_by_name['value']
_PRIMITIVE.oneofs_by_name['value'].fields.append(
  _PRIMITIVE.fields_by_name['bool_value'])
_PRIMITIVE.fields_by_name['bool_value'].containing_oneof = _PRIMITIVE.oneofs_by_name['value']
_CONDITION.fields_by_name['op'].enum_type = _OPERATOR
_CONDITION.fields_by_name['values'].message_type = _WHERE
DESCRIPTOR.message_types_by_name['Where'] = _WHERE
DESCRIPTOR.message_types_by_name['Primitive'] = _PRIMITIVE
DESCRIPTOR.message_types_by_name['Condition'] = _CONDITION
DESCRIPTOR.enum_types_by_name['Operator'] = _OPERATOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Where = _reflection.GeneratedProtocolMessageType('Where', (_message.Message,), dict(
  DESCRIPTOR = _WHERE,
  __module__ = 'anywhere.anywhere_pb2'
  # @@protoc_insertion_point(class_scope:anywhere.Where)
  ))
_sym_db.RegisterMessage(Where)

Primitive = _reflection.GeneratedProtocolMessageType('Primitive', (_message.Message,), dict(
  DESCRIPTOR = _PRIMITIVE,
  __module__ = 'anywhere.anywhere_pb2'
  # @@protoc_insertion_point(class_scope:anywhere.Primitive)
  ))
_sym_db.RegisterMessage(Primitive)

Condition = _reflection.GeneratedProtocolMessageType('Condition', (_message.Message,), dict(
  DESCRIPTOR = _CONDITION,
  __module__ = 'anywhere.anywhere_pb2'
  # @@protoc_insertion_point(class_scope:anywhere.Condition)
  ))
_sym_db.RegisterMessage(Condition)


# @@protoc_insertion_point(module_scope)
